@@ -11,11 +11,12 @@ from skippa import Skippa, columns
 
 def test_pipeline(test_data):
     """Test if the pipeline works, i.e. returns a dataframe"""
+    X, _ = test_data
     pipe = (
         Skippa()
         .select(columns())
         .build()
     )
-    res = pipe.fit_transform(test_data)
+    res = pipe.fit_transform(X)
     assert isinstance(res, pd.DataFrame)
-    assert test_data.shape == res.shape
+    assert X.shape == res.shape
